Class: PProf::OutputFormatter
- Inherits:
-
Object
- Object
- PProf::OutputFormatter
- Defined in:
- lib/pprof/output_formatter.rb
Overview
A helper tool to pretty-print Provisioning Profile informations
Defined Under Namespace
Classes: ASCIITable
Constant Summary collapse
- MAIN_PROFILE_KEYS =
List of properties of a
PProf::ProvisioningProfileto print when using the-iflag %i[name uuid app_id_name app_id_prefix creation_date expiration_date ttl team_ids team_name].freeze
Class Method Summary collapse
Instance Method Summary collapse
-
#as_json(profile, options = {}) ⇒ Hash
Returns a Provisioning Profile hash ready to be printed as a JSON output.
-
#filter_proc(filters = {}) ⇒ Lambda
Generates a lambda which takes a
PProf::ProvisioningProfileand returns if it should be kept in our listing or not. -
#initialize(output = $stdout) ⇒ OutputFormatter
constructor
Initialize a new OutputFormatter.
-
#print_error(message, file) ⇒ Object
Prints an error message.
-
#print_info(profile, options = nil) ⇒ Object
Prints the description of a Provisioning Profile.
-
#print_json(profile, options = {}) ⇒ Object
Prints a Provisioning Profile as JSON.
-
#print_json_list(options:, dir: PProf::ProvisioningProfile::DEFAULT_DIR) { ... } ⇒ Object
Prints the filtered list of profiles as a JSON array.
-
#print_list(options:, dir: PProf::ProvisioningProfile::DEFAULT_DIR) { ... } ⇒ Object
Prints the filtered list of UUIDs or Paths only.
-
#print_table(dir: PProf::ProvisioningProfile::DEFAULT_DIR) { ... } ⇒ Object
Prints the filtered list as a table.
Constructor Details
#initialize(output = $stdout) ⇒ OutputFormatter
Initialize a new OutputFormatter
18 19 20 |
# File 'lib/pprof/output_formatter.rb', line 18 def initialize(output = $stdout) @output = output end |
Class Method Details
.match_aps_env(actual, expected) ⇒ Object
261 262 263 264 265 266 |
# File 'lib/pprof/output_formatter.rb', line 261 def self.match_aps_env(actual, expected) return false if actual.nil? # false if no Push entitlements return true if expected == true # true if Push present but we don't filter on specific env actual =~ expected # true if Push present and we filter on specific env end |
Instance Method Details
#as_json(profile, options = {}) ⇒ Hash
Returns a Provisioning Profile hash ready to be printed as a JSON output
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/pprof/output_formatter.rb', line 111 def as_json(profile, = {}) hash = profile.to_hash.dup hash.delete 'DER-Encoded-Profile' hash.delete 'ProvisionedDevices' unless [:devices] if [:certs] hash['DeveloperCertificates'] = profile.developer_certificates.map do |cert| { subject: cert.subject, issuer: cert.issuer, serial: cert.serial, expires: cert.not_after } end else hash.delete 'DeveloperCertificates' end hash end |
#filter_proc(filters = {}) ⇒ Lambda
Generates a lambda which takes a PProf::ProvisioningProfile and returns if it should be kept in our listing or not
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/pprof/output_formatter.rb', line 149 def filter_proc(filters = {}) lambda do |p| (filters[:name].nil? || p.name =~ filters[:name]) && (filters[:appid_name].nil? || p.app_id_name =~ filters[:appid_name]) && (filters[:appid].nil? || p.entitlements.app_id =~ filters[:appid]) && (filters[:uuid].nil? || p.uuid =~ filters[:uuid]) && (filters[:team].nil? || p.team_name =~ filters[:team] || p.team_ids.any? { |id| id =~ filters[:team] }) && (filters[:exp].nil? || (p.expiration_date < DateTime.now) == filters[:exp]) && (filters[:has_devices].nil? || !(p.provisioned_devices || []).empty? == filters[:has_devices]) && (filters[:all_devices].nil? || p.provisions_all_devices == filters[:all_devices]) && (filters[:aps_env].nil? || match_aps_env(p.entitlements.aps_environment, filters[:aps_env])) && (filters[:platform].nil? || p.platform.include?(filters[:platform])) && true end end |
#print_error(message, file) ⇒ Object
Prints an error message
57 58 59 |
# File 'lib/pprof/output_formatter.rb', line 57 def print_error(, file) @output.puts "\u{274c} #{file} - #{}" end |
#print_info(profile, options = nil) ⇒ Object
Prints the description of a Provisioning Profile
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/pprof/output_formatter.rb', line 68 def print_info(profile, = nil) ||= { info: true } if [:info] keys = MAIN_PROFILE_KEYS keys.each do |key| @output.puts "- #{key}: #{profile.send(key.to_sym)}" end @output.puts '- Entitlements:' @output.puts(profile.entitlements.to_s.split("\n").map { |line| " #{line}" }) end # rubocop:disable Style/GuardClause if [:info] || [:certs] @output.puts "- #{profile.developer_certificates.count} Developer Certificates" if [:certs] profile.developer_certificates.each do |cert| @output.puts " - #{cert.subject}" @output.puts " issuer: #{cert.issuer}" @output.puts " serial: #{cert.serial}" @output.puts " expires: #{cert.not_after}" end end end if [:info] || [:devices] @output.puts "- #{(profile.provisioned_devices || []).count} Provisioned Devices" profile.provisioned_devices.each { |udid| @output.puts " - #{udid}" } if [:devices] @output.puts "- Provision all devices: #{profile.provisions_all_devices.inspect}" end # rubocop:enable Style/GuardClause end |
#print_json(profile, options = {}) ⇒ Object
Prints a Provisioning Profile as JSON
139 140 141 |
# File 'lib/pprof/output_formatter.rb', line 139 def print_json(profile, = {}) @output.puts JSON.pretty_generate(as_json(profile, )) end |
#print_json_list(options:, dir: PProf::ProvisioningProfile::DEFAULT_DIR) { ... } ⇒ Object
Prints the filtered list of profiles as a JSON array
248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/pprof/output_formatter.rb', line 248 def print_json_list(options:, dir: PProf::ProvisioningProfile::DEFAULT_DIR) errors = [] profiles = Dir['*.{mobileprovision,provisionprofile}', base: dir].map do |file_name| file = File.join(dir, file_name) p = PProf::ProvisioningProfile.new(file) as_json(p, ) unless block_given? && !yield(p) rescue StandardError => e errors << { message: e, file: file } end.compact errors.each { |e| print_error(e[:message], e[:file]) } unless errors.empty? @output.puts JSON.pretty_generate(profiles) end |
#print_list(options:, dir: PProf::ProvisioningProfile::DEFAULT_DIR) { ... } ⇒ Object
Prints the filtered list of UUIDs or Paths only
219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/pprof/output_formatter.rb', line 219 def print_list(options:, dir: PProf::ProvisioningProfile::DEFAULT_DIR) errors = [] Dir['*.{mobileprovision,provisionprofile}', base: dir].each do |file_name| file = File.join(dir, file_name) p = PProf::ProvisioningProfile.new(file) next if block_given? && !yield(p) @output.print [:mode] == :list ? p.uuid.chomp : file.chomp @output.print [:zero] ? "\0" : "\n" rescue StandardError => e errors << { message: e, file: file } end errors.each { |e| print_error(e[:message], e[:file]) } unless errors.empty? end |
#print_table(dir: PProf::ProvisioningProfile::DEFAULT_DIR) { ... } ⇒ Object
Prints the filtered list as a table
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/pprof/output_formatter.rb', line 175 def print_table(dir: PProf::ProvisioningProfile::DEFAULT_DIR) count = 0 errors = [] table = PProf::OutputFormatter::ASCIITable.new(36, 60, 45, 25, 2, 10) @output.puts table.separator @output.puts table.row('UUID', 'Name', 'AppID', 'Expiration Date', ' ', 'Team Name') @output.puts table.separator Dir['*.{mobileprovision,provisionprofile}', base: dir].each do |file_name| file = File.join(dir, file_name) begin p = PProf::ProvisioningProfile.new(file) next if block_given? && !yield(p) state = DateTime.now < p.expiration_date ? "\u{2705}" : "\u{274c}" # 2705=checkmark, 274C=red X @output.puts table.row(p.uuid, p.name, p.entitlements.app_id, p.expiration_date.to_time, state, p.team_name) rescue StandardError => e errors << { message: e, file: file } end count += 1 end @output.puts table.separator @output.puts "#{count} Provisioning Profiles found." errors.each { |e| print_error(e[:message], e[:file]) } unless errors.empty? end |